@@ -7,7 +7,7 @@ Ranking Metrics
 import torch
 
 
-class WMTKendall():
+class WMTKendall:
     def __init__(self):
         self.name = "kendall"
 
@@ -16,7 +16,7 @@ class WMTKendall():
     ) -> torch.Tensor:
         """Computes the level of concordance, discordance and the WMT kendall tau metric
 
-        :param distance_pos: distance between the positive samples and the anchor/s 
+        :param distance_pos: distance between the positive samples and the anchor/s
         :param distance_neg: distance between the negative samples and the anchor/s
 
         :return: Level of agreement, nº of positive sample closer to the anchor
