@@ -1,11 +1,9 @@
 from .tokenizer_base import TextEncoderBase
 from .hf_tokenizer import HFTextEncoder
-from .fastbpe_tokenizer import FastBPEEncoder
 from .xlmr_tokenizer import XLMRTextEncoder
 
 __all__ = [
     "XLMRTextEncoder",
     "HFTextEncoder",
-    "FastBPEEncoder",
     "TextEncoderBase",
 ]
